@@ -38,10 +38,12 @@ ID_PROFILE_FOLDER=${HOME}/.icedove
 TB_PROFILE_FOLDER=${HOME}/.thunderbird
 TB_GDB_DEFAULT_OPTS=${TB_GDB_DEFAULT_OPTS:-"-ex \"handle SIG38 nostop\" -ex \"handle SIGPIPE nostop\""}
 
-export HELP=0
-export FAIL=0
+export TB_HELP=0
+export TB_FAIL=0
 export FORCE_MIMEAPPS_MIGRATE=0
-export VERBOSE=0
+export TB_VERBOSE=0
+unset DEBUG
+unset DEBUGGER
 
 # set MOZ_APP_LAUNCHER for gnome-session
 export MOZ_APP_LAUNCHER
@@ -67,14 +69,14 @@ for ARG in "$@"; do
 #            shift
 #            ;;
         --help)
-            HELP=1
+            TB_HELP=1
             ;;
         --show-backup)
             SHOW_BACKUP=1
             ;;
         --verbose)
             output_info "[[ ... using verbose mode ... ]]"
-            VERBOSE=1
+            TB_VERBOSE=1
             ;;
         '?')
             usage >&2
@@ -97,7 +99,7 @@ fi
 
 # If '--help' was called show usage() and exit immediately without other
 # helpers can be called.
-if [ "${HELP}" = "1" ]; then
+if [ "${TB_HELP}" = "1" ]; then
     usage
     exit 0
 fi
@@ -229,7 +231,7 @@ elif { [ -d "${ID_PROFILE_FOLDER}" ] || [ -L "${ID_PROFILE_FOLDER}" ]; } && \
 
 fi
 
-if [ "${FAIL}" = 1 ]; then
+if [ "${TB_FAIL}" = 1 ]; then
     output_info "An error happened while trying to migrate the old Icedove profile folder '${ID_PROFILE_FOLDER}'."
     output_info "Please take a look into the syslog file!"
     exit 1
